@@ -85,3 +85,7 @@ class Mesh:
                 Mesh.release()
             else:
                 Mesh.pop()
+
+    @staticmethod
+    def context_id() -> str:
+        return f"{threading.currentThread().ident}-{threading.currentThread().name}"
