@@ -27,12 +27,12 @@ class GrpcProvider(Provider):
         self.interceptor = GrpcInterceptor()
         self.service = GrpcBindableService()
         self.server = grpc.server(
-            futures.ThreadPoolExecutor(max_workers=multiprocessing.cpu_count() * 3),
+            futures.ThreadPoolExecutor(max_workers=multiprocessing.cpu_count() * 10),
             [self.service],
             [self.interceptor],
             [('grpc.max_message_length', 1 << 29)],
             None,
-            True,
+            grpc.Compression.Gzip,
             False
         )
 
