@@ -6,7 +6,7 @@
 
 # https://stackoverflow.com/questions/33533148/how-do-i-type-hint-a-method-with-the-type-of-the-enclosing-class
 
-from typing import Generic, Dict, List, Type
+from typing import Generic, Dict, List, Type, Any
 
 from mesh.cause import NotFoundException
 from mesh.macro.ark import T, ark
@@ -14,6 +14,7 @@ from mesh.macro.spi import spi, SPI
 
 
 class Instance(Generic[T]):
+    values: Dict[type, Any] = {}
 
     def __init__(self, name: str, kind: type, prototype=False, pattern='', priority=0) -> None:
         self.name = name
@@ -21,7 +22,6 @@ class Instance(Generic[T]):
         self.prototype = prototype
         self.pattern = pattern
         self.priority = priority
-        self.value = None
 
     def __lt__(self, other):
         return self.priority > other.priority
@@ -29,9 +29,13 @@ class Instance(Generic[T]):
     def get_if_absent(self) -> T:
         if self.prototype:
             return self.create()
-        if self.value is None:
-            self.value = self.create()
-        return self.value
+
+        value = self.values.get(self.kind, None)
+
+        if value is None:
+            value = self.values[self.kind] = self.create()
+
+        return value
 
     def create(self) -> T:
         return self.kind()
