@@ -45,8 +45,9 @@ class MPS(Generic[T]):
         if type(fn) is str:
             self.name = fn
             return
-        self.name = str(type(fn))
+        self.name = fn.__name__
         self.kind = fn
+        ark.register(mps, self.name, self.kind, self)
 
     def __call__(self, *args, **kwargs) -> T:
         if not hasattr(self, 'kind') or self.kind == '':
