@@ -23,13 +23,15 @@ class ServiceProxy(MethodProxy):
 
     @staticmethod
     def static_proxy(kind: Type[T], metadata: mpi) -> T:
-        interface = kind
+        interfaces = [kind]
         if hasattr(kind, "__args__") and getattr(kind, "__args__") is not None:
-            interface = kind.__args__[0]
+            interfaces = kind.__args__
+
+        for interface in interfaces:
+            if not inspect.isabstract(interface):
+                raise ValidationException(f'{str(interface)} is not abstract class. ')
 
-        if not inspect.isabstract(interface):
-            raise ValidationException(f'{str(interface)} is not abstract class. ')
         if metadata is None:
             metadata = mpi()
 
-        return Proxy(kind, ReferenceInvokeHandler(metadata, kind))
+        return Proxy(interfaces, ReferenceInvokeHandler(metadata, interfaces))
